@@ -113,9 +113,7 @@ class Browser():
 				self.move(k)
 
 				
-			command = self.cardlist._hotkeys.get(k) or self.selected_card._hotkeys.get(k)
-			
-			if command:
+			if command := (self.cardlist._hotkeys.get(k) or self.selected_card._hotkeys.get(k)):
 				with AlternateScreen():
 					command()
 					if command in self.selected_card._confirm_exit_commands + self.cardlist._confirm_exit_commands:
@@ -123,8 +121,10 @@ class Browser():
 						readkey()
 
 			if generator := generators_dict.get(k):
-				new_card = generator()
-				self.cardlist.insert(self.sel, new_card)
+				with AlternateScreen():
+					new_card = generator()
+					self.cardlist.insert(self.sel, new_card)
+				ansi.down_line()
 				if self.N == FRAME_WIDTH + 1:
 					ansi.down_line()
 
