@@ -1,7 +1,5 @@
 from vinca.card import Card
-from vinca.generators.decorator import generator
 
-@generator
 def media():
 	''' make a card with audio and pictures '''
 	# initialize card
@@ -12,4 +10,4 @@ def media():
 	for side in ('front', 'back'):
 		(new_card.path / side).touch()
 	new_card.edit()  
-	return [new_card]
+	return new_card
