@@ -1,5 +1,5 @@
 from vinca.lib.terminal import AlternateScreen
-import readchar
+from vinca.lib.readkey import readkey
 
 def review(card):
 
@@ -8,13 +8,13 @@ def review(card):
 		lines = (card.path / 'lines').read_text().splitlines()
 		print(lines.pop(0))  # print the first line
 		for line in lines:
-			readchar.readchar()  # press any key to continue
+			readkey() # press any key to continue
 			# TODO abort
 			print(line)
 		print('\n(end)')
 
 		# grade the card
-		char = readchar.readchar()
+		char = readkey()
 	
 	return char
 
